#include <unordered_map>
#include <algorithm>
#include <iostream>
#include <numeric>
#include <cassert>
#include <vector>
#include <random>
#include <map>

typedef long long llong;
const int MAXN = 50 + 10;
const int STRING_SIZE = 50;
const int INF = 1e9;
const int TRIES = 1;

int n, m;
std::pair <int,int> delta[256];

bool outside(int row, int col)
{
    return row == -1 || col == -1 || row == n || col == m;
}

std::pair <int,int> apply(int x, int y, const std::string &s)
{
    int startX = 0;
    int startY = 0;

    for (int pos = 0 ; pos < s.size() ; ++pos)
    {
        int dx = delta[s[pos]].first;
        int dy = delta[s[pos]].second;
        if (outside(startX + dx, startY + dy) || (x == startX + dx && y == startY + dy))
        {
            continue;
        }

        startX += dx;
        startY += dy;
    }

    return {startX, startY};
}

void solve()
{
    delta['^'] = {-1, 0};
    delta['>'] = {0, 1};
    delta['v'] = {1, 0};
    delta['<'] = {0, -1};
    std::vector <std::pair <int,int>> possible;
    for (int i = 0 ; i < n ; ++i)
    {
        for (int j = 0 ; j < m ; ++j)
        {
            if (i == 0 && j == 0)
            {
                continue;
            }

            possible.push_back({i, j});
        }
    }

    // std::cout << "possible at first\n";
    std::mt19937 rng(987654321);
    while (possible.size() > 1)
    {
        int minDiff = possible.size();
        std::map <std::pair <int,int>, std::pair <int,int>> ansChoose, choose;
        std::map <std::pair <int,int>, int> currCnt;
        std::string ans, s; 
        ans.resize(STRING_SIZE);
        s.resize(STRING_SIZE);

        for (int currTry = 0 ; true ; ++currTry)
        {
            for (int i = 0 ; i < STRING_SIZE ; ++i)
            {
                int res = rng() & 3;
                if (res == 0) s[i] = '^';
                if (res == 1) s[i] = '>';
                if (res == 2) s[i] = 'v';
                if (res == 3) s[i] = '<';
            }

            choose.clear();
            currCnt.clear();
            for (const auto &[x, y] : possible)
            {
                choose[{x, y}] = apply(x, y, s);
                currCnt[choose[{x, y}]]++;
            }

            if (currCnt.size() == 1)
            {
                continue;
            }

            int max = 0, min = INF;
            for (const auto &[key, value] : currCnt)
            {
                max = std::max(max, value);
                min = std::min(min, value);
            }

            
            assert(min != INF);
            if (max - min < minDiff)
            {
                minDiff = max - min;
                ansChoose = choose;
                ans = s;
                break;
            }
        }

        std::cout << "? " << ans << '\n' << std::flush;
        int x, y;
        std::cin >> x >> y;
        int lastSize = possible.size();

        std::vector <std::pair <int,int>> newPossible;
        for (const auto &p : possible)
        {
            if (ansChoose[p].first == x && ansChoose[p].second == y)
            {
                newPossible.push_back(p);
            }
        }

        // std::cerr << "here: " << possible.size() << ' ' << newPossible.size() << ' ' << minDiff << '\n';
        possible = newPossible;
        assert(possible.size() < lastSize);
    }

    assert(possible.size() == 1);
    std::cout << "! " << possible[0].first << ' ' << possible[0].second << '\n';
}

void input()
{
    std::cin >> n >> m;
}

int main()
{
    input();
    solve();

    return 0;
}